This is a pythonic api for creating LookML objects.

get started fast:
`pip install lookml`

```
import lookml

order_items = lookml.View('order_items')

order_items + 'id' + 'value'

order_itmems.addSum('id')

print(order_items)

```

